@@ -26,11 +26,11 @@ from gajim.common.ged import EventHelper
 from gajim.common.i18n import _
 from gajim.common.logging_helpers import get_log_console_handler
 
+from gajim.gtk.alert import InformationAlertDialog
 from gajim.gtk.builder import get_builder
 from gajim.gtk.const import Setting
 from gajim.gtk.const import SettingKind
 from gajim.gtk.const import SettingType
-from gajim.gtk.dialogs import SimpleDialog
 from gajim.gtk.dropdown import GajimDropDown
 from gajim.gtk.settings import SettingsDialog
 from gajim.gtk.util.misc import at_the_end
@@ -93,13 +93,25 @@ class DebugConsoleWindow(GajimAppWindow, EventHelper):
         self._outgoing = True
 
         self._ui = get_builder("debug_console.ui")
-        self.window.set_titlebar(self._ui.headerbar)
+        header_bar = self.get_header_bar()
+        assert header_bar is not None
+        header_bar.set_title_widget(self._ui.header_box)
         self._set_title()
-
         self.set_child(self._ui.stack)
 
         self._ui.paned.set_position(self._ui.paned.get_property("max-position"))
 
+        action = Gio.SimpleAction.new("clear-window")
+        self._connect(action, "activate", self._on_clear_window)
+        self.window.add_action(action)
+
+        shortcut_controller = Gtk.ShortcutController()
+        callback_action = Gtk.CallbackAction.new(self._on_clear_window)  # type: ignore
+        shortcut_trigger = Gtk.ShortcutTrigger.parse_string("<Control>l")
+        shortcut = Gtk.Shortcut.new(shortcut_trigger, callback_action)
+        shortcut_controller.add_shortcut(shortcut)
+        self.window.add_controller(shortcut_controller)
+
         accounts = self._get_accounts()
         self._account_dropdown = GajimDropDown(fixed_width=15, data=accounts)
         if accounts:
@@ -120,7 +132,6 @@ class DebugConsoleWindow(GajimAppWindow, EventHelper):
         self._connect(
             self._ui.filter_options_button, "clicked", self._on_filter_options
         )
-        self._connect(self._ui.clear_button, "clicked", self._on_clear)
         self._connect(self._ui.paste, "clicked", self._on_paste_previous)
         self._connect(
             self._ui.stanza_presets_listbox, "row-activated", self._on_row_activated
@@ -313,7 +324,7 @@ class DebugConsoleWindow(GajimAppWindow, EventHelper):
             return
         if not app.account_is_available(self._selected_send_account):
             # If offline or connecting
-            SimpleDialog(
+            InformationAlertDialog(
                 _("Not Connected"),
                 _('Please make sure you are connected with "%s".')
                 % self._selected_send_account,
@@ -326,7 +337,7 @@ class DebugConsoleWindow(GajimAppWindow, EventHelper):
             try:
                 node = nbxmpp.Node(node=stanza)
             except Exception as error:
-                SimpleDialog(_("Invalid Node"), str(error))
+                InformationAlertDialog(_("Invalid Node"), str(error))
                 return
 
             if node.getName() in ("message", "presence", "iq"):
@@ -339,7 +350,7 @@ class DebugConsoleWindow(GajimAppWindow, EventHelper):
                         node=stanza, attrs={"xmlns": "jabber:client"}
                     )
                 except Exception as error:
-                    SimpleDialog(_("Invalid Stanza"), str(error))
+                    InformationAlertDialog(_("Invalid Stanza"), str(error))
                     return
 
             client = app.get_client(self._selected_send_account)
@@ -549,7 +560,7 @@ class DebugConsoleWindow(GajimAppWindow, EventHelper):
     def _on_filter_destroyed(self, _widget: Gtk.Widget) -> None:
         self._filter_dialog = None
 
-    def _on_clear(self, _button: Gtk.Button) -> None:
+    def _on_clear_window(self, *args: Any) -> None:
         self._ui.protocol_view.get_buffer().set_text("")
 
     def _apply_filters(self) -> None:
