@@ -31,13 +31,11 @@ from nbxmpp.structs import MuclumbusResult
 from nbxmpp.task import Task
 
 from gajim.common import app
-from gajim.common.configpaths import get_ui_path
 from gajim.common.const import AvatarSize
 from gajim.common.const import Direction
 from gajim.common.const import MUC_DISCO_ERRORS
 from gajim.common.const import PresenceShowExt
 from gajim.common.const import RFC5646_LANGUAGE_TAGS
-from gajim.common.const import URIType
 from gajim.common.helpers import to_user_string
 from gajim.common.i18n import _
 from gajim.common.i18n import get_rfc5646_lang
@@ -49,6 +47,7 @@ from gajim.common.util.muc import get_group_chat_nick
 from gajim.common.util.status import compare_show
 from gajim.common.util.text import to_one_line
 from gajim.common.util.uri import parse_uri
+from gajim.common.util.uri import XmppIri
 
 from gajim.gtk.builder import get_builder
 from gajim.gtk.chat_filter import ChatFilter
@@ -60,6 +59,7 @@ from gajim.gtk.menus import get_start_chat_menu
 from gajim.gtk.menus import get_start_chat_row_menu
 from gajim.gtk.util.classes import SignalManager
 from gajim.gtk.util.icons import get_icon_theme
+from gajim.gtk.util.misc import get_ui_string
 
 # from gajim.gtk.tooltips import ContactTooltip
 from gajim.gtk.widgets import AccountBadge
@@ -403,8 +403,8 @@ class StartChatDialog(GajimAppWindow):
 
         search_text = search_entry.get_text()
         uri = parse_uri(search_text)
-        if uri.type == URIType.XMPP:
-            search_entry.set_text(uri.data["jid"])
+        if isinstance(uri, XmppIri):
+            search_entry.set_text(str(uri.jid))
             return
 
         if search_text:
@@ -522,7 +522,6 @@ class StartChatDialog(GajimAppWindow):
             return
 
         self._ui.stack.set_visible_child_name("progress")
-        self._ui.spinner.start()
         client = app.get_client(item.account)
         client.get_module("Discovery").disco_info(
             item.jid, callback=self._disco_info_received, user_data=item, timeout=10
@@ -545,7 +544,7 @@ class StartChatDialog(GajimAppWindow):
                 return
 
             # Handle other possible errors
-            self._show_error_page(error.get_text())
+            self._show_error_page(to_user_string(error))
             return
         except TimeoutStanzaError:
             # We reached the 10s timeout and we cannot
@@ -564,7 +563,6 @@ class StartChatDialog(GajimAppWindow):
 
     def _disco_muc(self, account: str, jid: JID, request_vcard: bool) -> None:
         self._ui.stack.set_visible_child_name("progress")
-        self._ui.spinner.start()
         client = app.get_client(account)
         client.get_module("Discovery").disco_muc(
             jid,
@@ -651,7 +649,7 @@ class StartChatDialog(GajimAppWindow):
         if button.get_active():
             self._chat_filter.reset()
             self._chat_filter.set_sensitive(False)
-            image.add_css_class("selected-color")
+            image.add_css_class("accent")
             self._ui.list_stack.set_visible_child_name("global")
 
             self._ui.global_search_placeholder_stack.set_visible_child_name(
@@ -665,7 +663,7 @@ class StartChatDialog(GajimAppWindow):
         else:
             self._chat_filter.set_sensitive(True)
             self._ui.search_entry.set_text("")
-            image.remove_css_class("selected-color")
+            image.remove_css_class("accent")
             self._ui.list_stack.set_visible_child_name("contacts")
             self._global_search_view.remove_all()
 
@@ -963,8 +961,9 @@ class ContactListView(BaseListView[type["ContactListItem"], type["ContactViewIte
             return 1 if obj1.is_self else -1
 
         if app.settings.get("sort_by_show_in_start_chat"):
-            if obj1.show != obj2.show:
-                return compare_show(obj1.show, obj2.show)
+            res = compare_show(obj1.show, obj2.show)
+            if res != 0:
+                return res
 
         return locale.strcoll(obj1.name.lower(), obj2.name.lower())
 
@@ -1078,12 +1077,13 @@ class ContactListItem(GObject.Object):
         return f"ContactListItem: {self.props.account} - {self.props.jid}"
 
 
-@Gtk.Template(filename=get_ui_path("contact_view_item.ui"))
+@Gtk.Template(string=get_ui_string("contact_view_item.ui"))
 class ContactViewItem(Gtk.Grid, SignalManager):
     __gtype_name__ = "ContactViewItem"
 
     _avatar: Gtk.Label = Gtk.Template.Child()
     _name_label: Gtk.Label = Gtk.Template.Child()
+    _address_label: Gtk.Label = Gtk.Template.Child()
     _status_label: Gtk.Label = Gtk.Template.Child()
     _idle_badge: IdleBadge = Gtk.Template.Child()
     _account_badge: AccountBadge = Gtk.Template.Child()
@@ -1110,6 +1110,7 @@ class ContactViewItem(Gtk.Grid, SignalManager):
     def bind(self, obj: GlobalListItem) -> None:
         bind_spec = [
             ("name", self._name_label, "label"),
+            ("jid", self._address_label, "label"),
             ("status", self._status_label, "label"),
             ("status_visible", self._status_label, "visible"),
             ("avatar_paintable", self._avatar, "paintable"),
@@ -1233,7 +1234,7 @@ class GlobalListItem(GObject.Object):
         return f"GlobalListItem: {self.props.jid} {self.props.name}"
 
 
-@Gtk.Template(filename=get_ui_path("global_view_item.ui"))
+@Gtk.Template(string=get_ui_string("global_view_item.ui"))
 class GlobalViewItem(Gtk.Box):
     __gtype_name__ = "GlobalViewItem"
 
